(function (global, factory) {
  if (typeof define === "function" && define.amd) {
    define(['exports', 'react', 'draft-js', 'draft-js-export-markdown', './BlockStyleControls', './InlineStyleControls', './LinkControls', './ImageControls', './Link', './Media'], factory);
  } else if (typeof exports !== "undefined") {
    factory(exports, require('react'), require('draft-js'), require('draft-js-export-markdown'), require('./BlockStyleControls'), require('./InlineStyleControls'), require('./LinkControls'), require('./ImageControls'), require('./Link'), require('./Media'));
  } else {
    var mod = {
      exports: {}
    };
    factory(mod.exports, global.react, global.draftJs, global.draftJsExportMarkdown, global.BlockStyleControls, global.InlineStyleControls, global.LinkControls, global.ImageControls, global.Link, global.Media);
    global.RichTextEditor = mod.exports;
  }
})(this, function (exports, _react, _draftJs, _draftJsExportMarkdown, _BlockStyleControls, _InlineStyleControls, _LinkControls, _ImageControls, _Link, _Media) {
  'use strict';

  Object.defineProperty(exports, "__esModule", {
    value: true
  });

  var _react2 = _interopRequireDefault(_react);

  var _BlockStyleControls2 = _interopRequireDefault(_BlockStyleControls);

  var _InlineStyleControls2 = _interopRequireDefault(_InlineStyleControls);

  var _LinkControls2 = _interopRequireDefault(_LinkControls);

  var _ImageControls2 = _interopRequireDefault(_ImageControls);

  var _Link2 = _interopRequireDefault(_Link);

  var _Media2 = _interopRequireDefault(_Media);

  function _interopRequireDefault(obj) {
    return obj && obj.__esModule ? obj : {
      default: obj
    };
  }

  function _classCallCheck(instance, Constructor) {
    if (!(instance instanceof Constructor)) {
      throw new TypeError("Cannot call a class as a function");
    }
  }

  var _createClass = function () {
    function defineProperties(target, props) {
      for (var i = 0; i < props.length; i++) {
        var descriptor = props[i];
        descriptor.enumerable = descriptor.enumerable || false;
        descriptor.configurable = true;
        if ("value" in descriptor) descriptor.writable = true;
        Object.defineProperty(target, descriptor.key, descriptor);
      }
    }

    return function (Constructor, protoProps, staticProps) {
      if (protoProps) defineProperties(Constructor.prototype, protoProps);
      if (staticProps) defineProperties(Constructor, staticProps);
      return Constructor;
    };
  }();

  function _possibleConstructorReturn(self, call) {
    if (!self) {
      throw new ReferenceError("this hasn't been initialised - super() hasn't been called");
    }

    return call && (typeof call === "object" || typeof call === "function") ? call : self;
  }

  function _inherits(subClass, superClass) {
    if (typeof superClass !== "function" && superClass !== null) {
      throw new TypeError("Super expression must either be null or a function, not " + typeof superClass);
    }

    subClass.prototype = Object.create(superClass && superClass.prototype, {
      constructor: {
        value: subClass,
        enumerable: false,
        writable: true,
        configurable: true
      }
    });
    if (superClass) Object.setPrototypeOf ? Object.setPrototypeOf(subClass, superClass) : subClass.__proto__ = superClass;
  }

  var RichTextEditor = function (_React$Component) {
    _inherits(RichTextEditor, _React$Component);

    function RichTextEditor(props) {
      _classCallCheck(this, RichTextEditor);

      var _this = _possibleConstructorReturn(this, Object.getPrototypeOf(RichTextEditor).call(this, props));

      _this.findLinkEntities = function (contentBlock, callback) {
        contentBlock.findEntityRanges(function (character) {
          var entityKey = character.getEntity();
          return entityKey !== null && _draftJs.Entity.get(entityKey).getType() === 'LINK';
        }, callback);
      };

      _this.decorator = new _draftJs.CompositeDecorator([{
        strategy: _this.findLinkEntities,
        component: _Link2.default
      }]);

      _this.state = {
        editorState: _draftJs.EditorState.createEmpty(_this.decorator)
      };

      _this.focus = function () {
        return _this.refs.editor.focus();
      };
      _this.onChange = function (editorState) {
        return _this.setState({ editorState: editorState });
      };

      // This should be called on parent component: this.refs.editor.getMarkdown()
      _this.getMarkdown = function () {
        var contentState = _this.state.editorState.getCurrentContent();
        return (0, _draftJsExportMarkdown.stateToMarkdown)(contentState);
      };

      _this.blockTypes = [{ icon: 'header', style: 'header-one' }, { icon: 'font', style: 'header-two' }, { icon: 'quote-left', style: 'blockquote' }, { icon: 'list-ul', style: 'unordered-list-item' }, { icon: 'list-ol', style: 'ordered-list-item' }, { icon: 'code', style: 'code-block' }];

      _this.inlineStyles = [{ icon: 'bold', style: 'BOLD' }, { icon: 'italic', style: 'ITALIC' }, { icon: 'underline', style: 'UNDERLINE' }, { icon: 'code', style: 'CODE' }];
      return _this;
    }

    _createClass(RichTextEditor, [{
      key: 'handleKeyCommand',
      value: function handleKeyCommand(command) {
        var editorState = this.state.editorState;

        var newState = _draftJs.RichUtils.handleKeyCommand(editorState, command);
        if (newState) {
          this.onChange(newState);
          return true;
        }
        return false;
      }
    }, {
      key: 'toggleBlockType',
      value: function toggleBlockType(blockType) {
        this.onChange(_draftJs.RichUtils.toggleBlockType(this.state.editorState, blockType));
      }
    }, {
      key: 'toggleInlineStyle',
      value: function toggleInlineStyle(inlineStyle) {
        this.onChange(_draftJs.RichUtils.toggleInlineStyle(this.state.editorState, inlineStyle));
      }
    }, {
      key: 'confirmLink',
      value: function confirmLink(urlValue) {
        var _this2 = this;

        var editorState = this.state.editorState;

        var entityKey = _draftJs.Entity.create('LINK', 'MUTABLE', { url: urlValue });
        this.setState({
          editorState: _draftJs.RichUtils.toggleLink(editorState, editorState.getSelection(), entityKey)
        }, function () {
          setTimeout(function () {
            return _this2.refs.editor.focus();
          }, 0);
        });
      }
    }, {
      key: 'removeLink',
      value: function removeLink() {
        var editorState = this.state.editorState;

        var selection = editorState.getSelection();
        if (!selection.isCollapsed()) {
          this.setState({
            editorState: _draftJs.RichUtils.toggleLink(editorState, selection, null)
          });
        }
      }
    }, {
      key: 'blockRenderer',
      value: function blockRenderer(block) {
        if (block.getType() === 'atomic') {
          return { component: _Media2.default, editable: false };
        }
        return null;
      }
    }, {
      key: 'insertMedia',
      value: function insertMedia(entityKey) {
        var editorState = this.state.editorState;

        this.onChange(_draftJs.AtomicBlockUtils.insertAtomicBlock(editorState, entityKey, ' '));
      }
    }, {
      key: 'render',
      value: function render() {
        var editorState = this.state.editorState;
        var filePickerKey = this.props.filePickerKey;

        return _react2.default.createElement(
          'div',
          { id: 'rich-text-editor', className: 'callout' },
          _react2.default.createElement(
            'div',
            { className: 'toolbar' },
            _react2.default.createElement(_BlockStyleControls2.default, {
              editorState: editorState,
              onToggle: this.toggleBlockType.bind(this),
              blockTypes: this.blockTypes
            }),
            _react2.default.createElement(_InlineStyleControls2.default, {
              editorState: editorState,
              onToggle: this.toggleInlineStyle.bind(this),
              inlineStyles: this.inlineStyles
            }),
            _react2.default.createElement(_LinkControls2.default, {
              editorState: editorState,
              confirmLink: this.confirmLink.bind(this),
              removeLink: this.removeLink.bind(this)
            }),
            _react2.default.createElement(_ImageControls2.default, {
              editorState: editorState,
              insertMedia: this.insertMedia.bind(this),
              filePickerKey: filePickerKey
            })
          ),
          _react2.default.createElement(
            'div',
            {
              className: 'editor',
              style: { overflow: 'scroll', maxHeight: '75vh' },
              onClick: this.focus
            },
            _react2.default.createElement(_draftJs.Editor, {
              blockRendererFn: this.blockRenderer,
              editorState: editorState,
              handleKeyCommand: this.handleKeyCommand.bind(this),
              onChange: this.onChange,
              placeholder: 'Tell a story...',
              ref: 'editor',
              spellCheck: true
            })
          )
        );
      }
    }]);

    return RichTextEditor;
  }(_react2.default.Component);

  RichTextEditor.props = {
    filePickerKey: _react.PropTypes.string.isRequired
  };

  exports.default = RichTextEditor;
});