import React from 'react';
import ButtonGroup from './ButtonGroup';
import IconButton from './IconButton';

class LinkControls extends React.Component {
  constructor(props) {
    super(props);

    this.state = {
      urlValue: '',
    };

    this.onURLChange = (event) => this.setState({ urlValue: event.target.value });
    this.confirmLink = (event) => {
      event.preventDefault();
      this.props.confirmLink(this.state.urlValue);
      $('.reveal').foundation('close');
      this.setState({
        urlValue: '',
      });
    };
    this.removeLink = () => {
      this.props.removeLink()
    };
  }

  promptForLink() {
    const { editorState } = this.props;
    const selection = editorState.getSelection();
    if (!selection.isCollapsed()) {
      $('.reveal').foundation('open');
      this.setState({
        urlValue: '',
      }, () => {
        setTimeout(() => this.refs.url.focus(), 0);
      });
    }
  }

  hidePrompt(event) {
    event.preventDefault();
    $('.reveal').foundation('close');
  }

  onLinkInputKeyDown(event) {
    if (event.which === 13) {
      this.confirmLink(event);
    }
  }

  render() {
    return (
      <ButtonGroup>

        <div className="reveal" id="linkModal" data-reveal>
          <h1>Insert Link</h1>

          <input
            onChange={this.onURLChange}
            ref="url"
            type="text"
            value={this.state.urlValue}
            onKeyDown={this.onLinkInputKeyDown.bind(this)}
            placeholder="http://www.example.com"
          />

          <div className="expanded button-group">
            <button
              type="button"
              className="secondary button"
              onMouseDown={this.hidePrompt.bind(this)}
            >
              Cancel
            </button>
            <button
              type="button"
              className="button"
              onMouseDown={this.confirmLink}
            >
              Accept
            </button>
          </div>
        </div>

        <IconButton
          onToggle={this.promptForLink.bind(this)}
          icon="link"
          active={false}
        />
        <IconButton
          onToggle={this.removeLink}
          icon="chain-broken"
          active={false}
        />
      </ButtonGroup>
    );
  }
}

export default LinkControls;
